__all__ = (
    "hist",
    "fisher_info",
    "cramer_rao_uncert",
    "gaussianity",
)

from relaxed.ops.fisher_information import cramer_rao_uncert, fisher_info
from relaxed.ops.histograms import hist
from relaxed.ops.likelihood_gaussianity import gaussianity



from __future__ import annotations

__all__ = (
    "fisher_info",
    "cramer_rao_uncert",
)

from typing import Any

import jax
import jax.numpy as jnp
from chex import Array


def fisher_info(model: Any, pars: Array, data: Array) -> Array:
    return -jax.hessian(lambda p, d: model.logpdf(p, d)[0])(pars, data)


def cramer_rao_uncert(model: Any, pars: Array, data: Array) -> Array:
    inv = jnp.linalg.inv(fisher_info(model, pars, data))
    return jnp.sqrt(jnp.diagonal(inv))



from relaxed._version import version as __version__

__all__ = (
    "__version__",
    "hist",
    "cramer_rao_uncert",
    "fisher_info",
    "mle",
    "infer",
    "gaussianity",
)

from relaxed import infer, mle
from relaxed.ops import cramer_rao_uncert, fisher_info, gaussianity, hist
